==> eam-wshub-proxyclient-11.4-11-sources.jar: net/datastream/schemas/mp_fields/CUSTOMFIELDELEMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CUSTOMFIELDELEMENTID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMFIELDELEMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMFIELDELEMENTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMFIELDELEMENTTEXT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMFIELDELEMENTID_Type", propOrder = {
    "customfieldelementcode",
    "customfieldelementtext"
})
public class CUSTOMFIELDELEMENTID_Type {

    @XmlElement(name = "CUSTOMFIELDELEMENTCODE", required = true)
    protected String customfieldelementcode;
    @XmlElement(name = "CUSTOMFIELDELEMENTTEXT")
    protected String customfieldelementtext;

    /**
     * Obtient la valeur de la propriété customfieldelementcode.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMFIELDELEMENTCODE() {
        return customfieldelementcode;
    }

    /**
     * Définit la valeur de la propriété customfieldelementcode.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMFIELDELEMENTCODE(String value) {
        this.customfieldelementcode = value;
    }

    /**
     * Obtient la valeur de la propriété customfieldelementtext.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMFIELDELEMENTTEXT() {
        return customfieldelementtext;
    }

    /**
     * Définit la valeur de la propriété customfieldelementtext.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMFIELDELEMENTTEXT(String value) {
        this.customfieldelementtext = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_fields/CUSTOMFIELDELEMENTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for CUSTOMFIELDELEMENTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="CUSTOMFIELDELEMENTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMFIELDELEMENTCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMFIELDELEMENTTEXT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CUSTOMFIELDELEMENTID_Type", propOrder = {
    "customfieldelementcode",
    "customfieldelementtext"
})
public class CUSTOMFIELDELEMENTID_Type {

    @XmlElement(name = "CUSTOMFIELDELEMENTCODE", required = true)
    protected String customfieldelementcode;
    @XmlElement(name = "CUSTOMFIELDELEMENTTEXT")
    protected String customfieldelementtext;

    /**
     * Gets the value of the customfieldelementcode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMFIELDELEMENTCODE() {
        return customfieldelementcode;
    }

    /**
     * Sets the value of the customfieldelementcode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMFIELDELEMENTCODE(String value) {
        this.customfieldelementcode = value;
    }

    /**
     * Gets the value of the customfieldelementtext property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCUSTOMFIELDELEMENTTEXT() {
        return customfieldelementtext;
    }

    /**
     * Sets the value of the customfieldelementtext property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCUSTOMFIELDELEMENTTEXT(String value) {
        this.customfieldelementtext = value;
    }

}
